@@ -212,7 +212,7 @@ def copyshp(src, dst, env):
     """
     src,dst = sformat(src, env),sformat(dst, env)
     res = copyfile(src, dst, env)
-    if justpath(src).lower()=="shp":
+    if justext(src).lower()=="shp":
         for ext in ("dbf","shx","prj","qpj"):
             src = forceext(src,ext)
             if os.path.isfile(src):
